ManifestPermissionEntry class

Represents a permission entry in AndroidManifest.xml.

Inheritance

Constructors

ManifestPermissionEntry({required String key, required List<String> comments})
Default constructor.

Properties

comments → List<String>
Comments associated with the entry.
finalinherited
generatesCode → bool
Whether this entry is associated with generated code.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isLegacy → bool
Whether this entry is marked as legacy.
no setterinherited
key → String
The key/name of the entry.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override