XmlElementInfo class

A class representing information about an XML element to be inserted.

Constructors

XmlElementInfo({required String name, Map<String, String> attributes = const {}, String? content, List<String>? comments, bool isSelfClosing = false})
Default constructor.

Properties

attributes → Map<String, String>
Attributes of the XML element.
final
comments → List<String>?
Comments associated with the XML element (if any).
final
content → String?
The content of the XML element (if any).
final
hashCode → int
The hash code for this object.
no setterinherited
isSelfClosing → bool
Whether the element is self-closing.
final
name → String
The name of the XML element.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildEvents(String indent) → List<XmlEvent>
Builds the XML events for this element.
matches(XmlStartElementEvent event) → bool
Checks if the given event matches this element info.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited