XmlInsertElementEdit class

An edit operation to insert new XML elements.

Inheritance

Constructors

XmlInsertElementEdit({required String path, required List<XmlElementInfo> tags, ElementAnchorPredicate? insertAfter})
Default constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertAfter → ElementAnchorPredicate?
An optional predicate to determine the anchor point for insertion.
final
path → String
The XML path where the edit should be applied.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<XmlElementInfo>
The list of elements to insert.
final

Methods

buildEvents(String indent) → List<XmlEvent>
Builds the XML events for the elements to insert.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited