XmlRemoveElementEdit class

An edit operation to remove XML elements.

Inheritance

Constructors

XmlRemoveElementEdit({required String path, required String tag, String? content, Map<String, String>? attributes, String? removeNextTag, RemoveComment? commentRemover})
Default constructor.

Properties

attributes → Map<String, String>?
Optional attributes to match for removal.
final
commentRemover → RemoveComment?
An optional function to determine whether to remove associated comments.
final
content → String?
Optional content to match for removal.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
The XML path where the edit should be applied.
finalinherited
removeNextTag → String?
An optional tag name of the next element to remove after the main one.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
The tag name of the element to remove.
final

Methods

matches(XmlStartElementEvent event, XmlTextEvent? contentEvent) → bool
Checks if the given event matches the removal criteria.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited