PluginGradleTemp class

Template for generating the build.gradle.kts for a plugin package.

Includes configuration for Android SDK versions and Java compatibility.

Inheritance

Constructors

PluginGradleTemp({String androidPackageName = kAndroidPackageName, int compileSdk = 35, int minSdk = 16})
Constructor for PluginGradleTemp.

Properties

androidPackageName → String
The Android package name for the plugin.
final
compileSdk → int
The compile SDK version.
final
hashCode → int
The hash code for this object.
no setterinherited
minSdk → int
The minimum SDK version.
final
path → String
The file path where the generated template will be saved.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → String
Generates the content of the template as a string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited