PluginPodTemp class

Template for generating the iOS podspec file for a plugin package.

This file is used by CocoaPods to manage the iOS dependencies of the plugin.

Inheritance

Constructors

PluginPodTemp({String pluginName = kDartPackageName, String minIosVersion = '12.0'})
Constructor for PluginPodTemp.

Properties

hashCode → int
The hash code for this object.
no setterinherited
minIosVersion → String
The minimum iOS version supported by the plugin.
final
path → String
The file path where the generated template will be saved.
no setteroverride
pluginName → String
The name of the plugin.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → String
Generates the content of the template as a string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited