PermissionGetterSnippet class

Snippet for generating a permission getter.

Constructors

PermissionGetterSnippet(String name, {required List<PermissionDef> entries})
Constructor for PermissionGetterSnippet.

Properties

entries List<PermissionDef>
The list of permission definitions for this permission.
final
hashCode int
The hash code for this object.
no setterinherited
hasService bool
Indicates if any entry has an associated service.
no setter
name String
The name of the permission.
final
platforms Set<String>
The set of platforms this permission applies to.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() String
Generates the Dart code snippet for this permission getter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited