PluginPubspecTemp class

Template for generating the pubspec.yaml for a plugin package.

Inheritance

Constructors

PluginPubspecTemp({String dartConstraint = kDefaultDartConstraint, String packageName = kDartPackageName, String androidPackageName = kAndroidPackageName, bool android = true, bool ios = true})
Constructor for PluginPubspecTemp.

Properties

android → bool
Whether to include Android platform support.
final
androidPackageName → String
The Android package name for the plugin.
final
dartConstraint → String
The Dart SDK constraint to use.
final
hashCode → int
The hash code for this object.
no setterinherited
ios → bool
Whether to include iOS platform support.
final
packageName → String
The name of the package.
final
path → String
The file path where the generated template will be saved.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → String
Generates the content of the template as a string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited