Template class abstract

Template base class This class defines the interface for code templates used in code generation.

Implementers

Constructors

Template()
Factory constructor to create a default template instance.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
The file path where the generated template will be saved.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → String
Generates the content of the template as a string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited