KotlinHandlerSnippet class
Represents a Kotlin permission handler snippet.
Constructors
-
KotlinHandlerSnippet({required String key, required List<
AndroidPermissionDef> permissions, Set<String> ? imports}) - Constructor for KotlinHandlerSnippet.
Properties
- className → String
-
The class name for this handler.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Set<
String> ? -
The imports required for this handler.
final
- key → String
-
Constructor for KotlinHandlerSnippet.
final
-
permissions
→ List<
AndroidPermissionDef> -
The permissions associated with this handler.
final
-
permissionsArray
→ Iterable<
String> -
The array of permissions for this handler.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → AssociatedService?
-
The associated service, if any.
latefinal
Methods
-
generate(
int requestCode) → String - Generates the Kotlin code for this handler.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited